# Real memory usage test case

use strict;
use warnings;

my $string;

$string = 'x' x (1024 * 1024 * 2);

print "Hello world\n";
